/*
 * Copyright 2017 Google Inc. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#extension GL_OES_EGL_image_external : require

precision mediump float;
varying vec2 v_TexCoord;
uniform samplerExternalOES sTexture;


const float M_PI_2 = 1.5707963267948966192313216916398;
const float M_2_PI = 0.63661977236758134307553505349006;

uniform float wh_ratio;
uniform int is_zoomed;
uniform float zoom_value; // [0,1], 0 - not zoomed, 1 - fully zoomed
uniform vec2 magnifier_position;
uniform vec2 zoom_position; // [0,1]ox[0,1]
uniform float zoom_area_r;
uniform float zoom_max;
uniform float offset;

void main() {

    /*float off = 0.1;
    if(v_TexCoord.ox < off && v_TexCoord.y < off){
        gl_FragColor = vec4(1,0,0,1);
        return;
    }
    if(v_TexCoord.ox < off && v_TexCoord.y > 1.0 - off){
        gl_FragColor = vec4(0,1,0,1);
        return;
    }
    if(v_TexCoord.ox > 1.0 - off && v_TexCoord.y < off){
        gl_FragColor = vec4(0,0,1,1);
        return;
    }
    if(v_TexCoord.ox > 1.0 - off && v_TexCoord.y > 1.0 - off){
        gl_FragColor = vec4(1,1,0,1);
        return;
    }

    if( v_TexCoord.ox > 0.5 - off && v_TexCoord.ox < 0.5 + off &&
        v_TexCoord.y > 0.5 - off && v_TexCoord.y < 0.5 + off){
        gl_FragColor = vec4(1,1,1,0.5);
        return;
    }*/

    if(is_zoomed > 0){

        mediump vec2 dr = (v_TexCoord - magnifier_position);
        float d = length(dr * vec2(1.0, wh_ratio));

        if(d < zoom_area_r)
        {
            float t = d / zoom_area_r;

            if(t < 0.85)
            {
                gl_FragColor = texture2D(sTexture, zoom_position + dr/zoom_max);
            }else{

                t = 1.0 - asin(pow((t-0.85)/0.15,4.0)) * M_2_PI;
                gl_FragColor = texture2D(sTexture, zoom_position + dr/(1.0 + t*(zoom_max-1.0)));
            }

        }else{

           gl_FragColor = texture2D(sTexture, v_TexCoord);
        }
    }else{

	    gl_FragColor = texture2D(sTexture, v_TexCoord);
    }
}
